@@ -123,7 +123,7 @@ class Dialog(models.Model):
 
     def load_in(self):
         wf = self.get_word_files()
-        for f in wf:
+        #for f in wf:
 
 
 class SegmentType(models.Model):
